@@ -591,6 +591,7 @@ class KDEVPYTHONPARSER_EXPORT StringAst : public ExpressionAst {
 public:
     StringAst(Ast* parent);
     QString value;
+    bool usedAsComment;
 };
 
 class KDEVPYTHONPARSER_EXPORT BytesAst : public ExpressionAst {
@@ -714,6 +715,7 @@ class KDEVPYTHONPARSER_EXPORT ArgumentsAst : public Ast {
 public:
     ArgumentsAst(Ast* parent);
     QList<ArgAst*> arguments;
+    QList<ArgAst*> kwonlyargs;
     QList<ExpressionAst*> defaultValues;
     ArgAst* vararg;
     ArgAst* kwarg;
